Class: Google::Apis::NotebooksV1::LocalDisk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v1/classes.rb,
lib/google/apis/notebooks_v1/representations.rb,
lib/google/apis/notebooks_v1/representations.rb

Overview

A Local attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalDisk

Returns a new instance of LocalDisk.



1587
1588
1589
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Optional. Output only. Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


1504
1505
1506
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1504

def auto_delete
  @auto_delete
end

#bootBoolean Also known as: boot?

Optional. Output only. Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem. Corresponds to the JSON property boot

Returns:

  • (Boolean)


1511
1512
1513
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1511

def boot
  @boot
end

#device_nameString

Optional. Output only. Specifies a unique device name of your choice that is reflected into the /dev/disk/by-id/google-* tree of a Linux operating system running within the instance. This name can be used to reference the device for mounting, resizing, and so on, from within the instance. If not specified, the server chooses a default device name to apply to this disk, in the form persistent-disk-x, where x is a number assigned by Google Compute Engine. This field is only applicable for persistent disks. Corresponds to the JSON property deviceName

Returns:

  • (String)


1523
1524
1525
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1523

def device_name
  @device_name
end

#guest_os_featuresArray<Google::Apis::NotebooksV1::RuntimeGuestOsFeature>

Output only. Indicates a list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



1530
1531
1532
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1530

def guest_os_features
  @guest_os_features
end

#indexFixnum

Output only. A zero-based index to this disk, where 0 is reserved for the boot disk. If you have many disks attached to an instance, each disk would have a unique index number. Corresponds to the JSON property index

Returns:

  • (Fixnum)


1537
1538
1539
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1537

def index
  @index
end

#initialize_paramsGoogle::Apis::NotebooksV1::LocalDiskInitializeParams

Input only. Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new runtime. This property is mutually exclusive with the source property; you can only define one or the other, but not both. Corresponds to the JSON property initializeParams



1545
1546
1547
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1545

def initialize_params
  @initialize_params
end

#interfaceString

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI. Persistent disks must always use SCSI and the request will fail if you attempt to attach a persistent disk in any other format than SCSI. Local SSDs can use either NVME or SCSI. For performance characteristics of SCSI over NVMe, see Local SSD performance. Valid values: * NVME * SCSI Corresponds to the JSON property interface

Returns:

  • (String)


1555
1556
1557
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1555

def interface
  @interface
end

#kindString

Output only. Type of the resource. Always compute#attachedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


1561
1562
1563
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1561

def kind
  @kind
end

#licensesArray<String>

Output only. Any valid publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


1566
1567
1568
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1566

def licenses
  @licenses
end

#modeString

The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. Valid values: * READ_ONLY * READ_WRITE Corresponds to the JSON property mode

Returns:

  • (String)


1573
1574
1575
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1573

def mode
  @mode
end

#sourceString

Specifies a valid partial or full URL to an existing Persistent Disk resource. Corresponds to the JSON property source

Returns:

  • (String)


1578
1579
1580
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1578

def source
  @source
end

#typeString

Specifies the type of the disk, either SCRATCH or PERSISTENT. If not specified, the default is PERSISTENT. Valid values: * PERSISTENT * SCRATCH Corresponds to the JSON property type

Returns:

  • (String)


1585
1586
1587
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1585

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1592

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @boot = args[:boot] if args.key?(:boot)
  @device_name = args[:device_name] if args.key?(:device_name)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @index = args[:index] if args.key?(:index)
  @initialize_params = args[:initialize_params] if args.key?(:initialize_params)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @licenses = args[:licenses] if args.key?(:licenses)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
  @type = args[:type] if args.key?(:type)
end