Class: Google::Apis::NotebooksV1::LocalDiskInitializeParams
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV1::LocalDiskInitializeParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v1/classes.rb,
lib/google/apis/notebooks_v1/representations.rb,
lib/google/apis/notebooks_v1/representations.rb
Overview
Input only. Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new runtime. This property is mutually exclusive with the source property; you can only define one or the other, but not both.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#disk_name ⇒ String
Optional.
-
#disk_size_gb ⇒ Fixnum
Optional.
-
#disk_type ⇒ String
Input only.
-
#labels ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocalDiskInitializeParams
constructor
A new instance of LocalDiskInitializeParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocalDiskInitializeParams
Returns a new instance of LocalDiskInitializeParams.
1646 1647 1648 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Provide this property when creating the disk.
Corresponds to the JSON property description
1618 1619 1620 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1618 def description @description end |
#disk_name ⇒ String
Optional. Specifies the disk name. If not specified, the default is to use the
name of the instance. If the disk with the instance name exists already in the
given zone/region, a new name will be automatically generated.
Corresponds to the JSON property diskName
1625 1626 1627 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1625 def disk_name @disk_name end |
#disk_size_gb ⇒ Fixnum
Optional. Specifies the size of the disk in base-2 GB. If not specified, the
disk will be the same size as the image (usually 10GB). If specified, the size
must be equal to or larger than 10GB. Default 100 GB.
Corresponds to the JSON property diskSizeGb
1632 1633 1634 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1632 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Input only. The type of the boot disk attached to this instance, defaults to
standard persistent disk (PD_STANDARD).
Corresponds to the JSON property diskType
1638 1639 1640 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1638 def disk_type @disk_type end |
#labels ⇒ Hash<String,String>
Optional. Labels to apply to this disk. These can be later modified by the
disks.setLabels method. This field is only applicable for persistent disks.
Corresponds to the JSON property labels
1644 1645 1646 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1644 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1651 1652 1653 1654 1655 1656 1657 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1651 def update!(**args) @description = args[:description] if args.key?(:description) @disk_name = args[:disk_name] if args.key?(:disk_name) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @labels = args[:labels] if args.key?(:labels) end |