Class: Google::Apis::NotebooksV1::MigrateRuntimeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v1/classes.rb,
lib/google/apis/notebooks_v1/representations.rb,
lib/google/apis/notebooks_v1/representations.rb

Overview

Request for migrating a Runtime to a Workbench Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrateRuntimeRequest

Returns a new instance of MigrateRuntimeRequest.



1767
1768
1769
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Optional. Name of the VPC that the new Instance is in. This is required if the Runtime uses google-managed network. If the Runtime uses customer-owned network, it will reuse the same VPC, and this field must be empty. Format: projects/project_id/global/networks/network_id` Corresponds to the JSON propertynetwork`

Returns:

  • (String)


1736
1737
1738
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1736

def network
  @network
end

#post_startup_script_optionString

Optional. Specifies the behavior of post startup script during migration. Corresponds to the JSON property postStartupScriptOption

Returns:

  • (String)


1741
1742
1743
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1741

def post_startup_script_option
  @post_startup_script_option
end

#request_idString

Optional. Idempotent request UUID. Corresponds to the JSON property requestId

Returns:

  • (String)


1746
1747
1748
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1746

def request_id
  @request_id
end

#service_accountString

Optional. The service account to be included in the Compute Engine instance of the new Workbench Instance when the Runtime uses "single user only" mode for permission. If not specified, the Compute Engine default service account is used. When the Runtime uses service account mode for permission, it will reuse the same service account, and this field must be empty. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1757
1758
1759
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1757

def 
  @service_account
end

#subnetString

Optional. Name of the subnet that the new Instance is in. This is required if the Runtime uses google-managed network. If the Runtime uses customer-owned network, it will reuse the same subnet, and this field must be empty. Format: projects/project_id/regions/region/subnetworks/subnetwork_id` Corresponds to the JSON propertysubnet`

Returns:

  • (String)


1765
1766
1767
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1765

def subnet
  @subnet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1772
1773
1774
1775
1776
1777
1778
# File 'lib/google/apis/notebooks_v1/classes.rb', line 1772

def update!(**args)
  @network = args[:network] if args.key?(:network)
  @post_startup_script_option = args[:post_startup_script_option] if args.key?(:post_startup_script_option)
  @request_id = args[:request_id] if args.key?(:request_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @subnet = args[:subnet] if args.key?(:subnet)
end