Class: Google::Apis::NotebooksV1::RuntimeSoftwareConfig
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV1::RuntimeSoftwareConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v1/classes.rb,
lib/google/apis/notebooks_v1/representations.rb,
lib/google/apis/notebooks_v1/representations.rb
Overview
Specifies the selection and configuration of software inside the runtime. The
properties to set on runtime. Properties keys are specified in key:value
format, for example: * idle_shutdown: true * idle_shutdown_timeout: 180 *
enable_health_monitoring: true
Instance Attribute Summary collapse
-
#custom_gpu_driver_path ⇒ String
Specify a custom Cloud Storage path where the GPU driver is stored.
-
#disable_terminal ⇒ Boolean
(also: #disable_terminal?)
Bool indicating whether JupyterLab terminal will be available or not.
-
#enable_health_monitoring ⇒ Boolean
(also: #enable_health_monitoring?)
Verifies core internal services are running.
-
#idle_shutdown ⇒ Boolean
(also: #idle_shutdown?)
Runtime will automatically shutdown after idle_shutdown_time.
-
#idle_shutdown_timeout ⇒ Fixnum
Time in minutes to wait before shutting down runtime.
-
#install_gpu_driver ⇒ Boolean
(also: #install_gpu_driver?)
Install Nvidia Driver automatically.
-
#kernels ⇒ Array<Google::Apis::NotebooksV1::ContainerImage>
Optional.
-
#mixer_disabled ⇒ Boolean
(also: #mixer_disabled?)
Bool indicating whether mixer client should be disabled.
-
#notebook_upgrade_schedule ⇒ String
Cron expression in UTC timezone, used to schedule instance auto upgrade.
-
#post_startup_script ⇒ String
Path to a Bash script that automatically runs after a notebook instance fully boots up.
-
#post_startup_script_behavior ⇒ String
Behavior for the post startup script.
-
#upgradeable ⇒ Boolean
(also: #upgradeable?)
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeSoftwareConfig
constructor
A new instance of RuntimeSoftwareConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeSoftwareConfig
Returns a new instance of RuntimeSoftwareConfig.
2586 2587 2588 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_gpu_driver_path ⇒ String
Specify a custom Cloud Storage path where the GPU driver is stored. If not
specified, we'll automatically choose from official GPU drivers.
Corresponds to the JSON property customGpuDriverPath
2511 2512 2513 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2511 def custom_gpu_driver_path @custom_gpu_driver_path end |
#disable_terminal ⇒ Boolean Also known as: disable_terminal?
Bool indicating whether JupyterLab terminal will be available or not. Default:
False
Corresponds to the JSON property disableTerminal
2517 2518 2519 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2517 def disable_terminal @disable_terminal end |
#enable_health_monitoring ⇒ Boolean Also known as: enable_health_monitoring?
Verifies core internal services are running. Default: True
Corresponds to the JSON property enableHealthMonitoring
2523 2524 2525 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2523 def enable_health_monitoring @enable_health_monitoring end |
#idle_shutdown ⇒ Boolean Also known as: idle_shutdown?
Runtime will automatically shutdown after idle_shutdown_time. Default: True
Corresponds to the JSON property idleShutdown
2529 2530 2531 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2529 def idle_shutdown @idle_shutdown end |
#idle_shutdown_timeout ⇒ Fixnum
Time in minutes to wait before shutting down runtime. Default: 180 minutes
Corresponds to the JSON property idleShutdownTimeout
2535 2536 2537 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2535 def idle_shutdown_timeout @idle_shutdown_timeout end |
#install_gpu_driver ⇒ Boolean Also known as: install_gpu_driver?
Install Nvidia Driver automatically. Default: True
Corresponds to the JSON property installGpuDriver
2540 2541 2542 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2540 def install_gpu_driver @install_gpu_driver end |
#kernels ⇒ Array<Google::Apis::NotebooksV1::ContainerImage>
Optional. Use a list of container images to use as Kernels in the notebook
instance.
Corresponds to the JSON property kernels
2547 2548 2549 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2547 def kernels @kernels end |
#mixer_disabled ⇒ Boolean Also known as: mixer_disabled?
Bool indicating whether mixer client should be disabled. Default: False
Corresponds to the JSON property mixerDisabled
2552 2553 2554 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2552 def mixer_disabled @mixer_disabled end |
#notebook_upgrade_schedule ⇒ String
Cron expression in UTC timezone, used to schedule instance auto upgrade.
Please follow the cron format.
Corresponds to the JSON property notebookUpgradeSchedule
2559 2560 2561 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2559 def notebook_upgrade_schedule @notebook_upgrade_schedule end |
#post_startup_script ⇒ String
Path to a Bash script that automatically runs after a notebook instance fully
boots up. The path must be a URL or Cloud Storage path (gs://path-to-file/
file-name).
Corresponds to the JSON property postStartupScript
2566 2567 2568 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2566 def post_startup_script @post_startup_script end |
#post_startup_script_behavior ⇒ String
Behavior for the post startup script.
Corresponds to the JSON property postStartupScriptBehavior
2571 2572 2573 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2571 def post_startup_script_behavior @post_startup_script_behavior end |
#upgradeable ⇒ Boolean Also known as: upgradeable?
Output only. Bool indicating whether an newer image is available in an image
family.
Corresponds to the JSON property upgradeable
2577 2578 2579 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2577 def upgradeable @upgradeable end |
#version ⇒ String
Output only. version of boot image such as M100, from release label of the
image.
Corresponds to the JSON property version
2584 2585 2586 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2584 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2591 def update!(**args) @custom_gpu_driver_path = args[:custom_gpu_driver_path] if args.key?(:custom_gpu_driver_path) @disable_terminal = args[:disable_terminal] if args.key?(:disable_terminal) @enable_health_monitoring = args[:enable_health_monitoring] if args.key?(:enable_health_monitoring) @idle_shutdown = args[:idle_shutdown] if args.key?(:idle_shutdown) @idle_shutdown_timeout = args[:idle_shutdown_timeout] if args.key?(:idle_shutdown_timeout) @install_gpu_driver = args[:install_gpu_driver] if args.key?(:install_gpu_driver) @kernels = args[:kernels] if args.key?(:kernels) @mixer_disabled = args[:mixer_disabled] if args.key?(:mixer_disabled) @notebook_upgrade_schedule = args[:notebook_upgrade_schedule] if args.key?(:notebook_upgrade_schedule) @post_startup_script = args[:post_startup_script] if args.key?(:post_startup_script) @post_startup_script_behavior = args[:post_startup_script_behavior] if args.key?(:post_startup_script_behavior) @upgradeable = args[:upgradeable] if args.key?(:upgradeable) @version = args[:version] if args.key?(:version) end |