Class: Google::Apis::NotebooksV1::ShieldedInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v1/classes.rb,
lib/google/apis/notebooks_v1/representations.rb,
lib/google/apis/notebooks_v1/representations.rb

Overview

A set of Shielded Instance options. See Images using supported Shielded VM features. Not all combinations are valid.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShieldedInstanceConfig

Returns a new instance of ShieldedInstanceConfig.



2862
2863
2864
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_integrity_monitoringBoolean Also known as: enable_integrity_monitoring?

Defines whether the instance has integrity monitoring enabled. Enables monitoring and attestation of the boot integrity of the instance. The attestation is performed against the integrity policy baseline. This baseline is initially derived from the implicitly trusted boot image when the instance is created. Enabled by default. Corresponds to the JSON property enableIntegrityMonitoring

Returns:

  • (Boolean)


2844
2845
2846
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2844

def enable_integrity_monitoring
  @enable_integrity_monitoring
end

#enable_secure_bootBoolean Also known as: enable_secure_boot?

Defines whether the instance has Secure Boot enabled. Secure Boot helps ensure that the system only runs authentic software by verifying the digital signature of all boot components, and halting the boot process if signature verification fails. Disabled by default. Corresponds to the JSON property enableSecureBoot

Returns:

  • (Boolean)


2853
2854
2855
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2853

def enable_secure_boot
  @enable_secure_boot
end

#enable_vtpmBoolean Also known as: enable_vtpm?

Defines whether the instance has the vTPM enabled. Enabled by default. Corresponds to the JSON property enableVtpm

Returns:

  • (Boolean)


2859
2860
2861
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2859

def enable_vtpm
  @enable_vtpm
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2867
2868
2869
2870
2871
# File 'lib/google/apis/notebooks_v1/classes.rb', line 2867

def update!(**args)
  @enable_integrity_monitoring = args[:enable_integrity_monitoring] if args.key?(:enable_integrity_monitoring)
  @enable_secure_boot = args[:enable_secure_boot] if args.key?(:enable_secure_boot)
  @enable_vtpm = args[:enable_vtpm] if args.key?(:enable_vtpm)
end